@@ -69,6 +69,8 @@ class ReportDocx(Report):
         print(f"SAVED TO {pathOutput}")
         self._deleteAllTempPlots()
 
+
+
     def setImage(self,
                  tag: str,
                  path: typ.Union[str, pth.Path],
@@ -106,12 +108,12 @@ class ReportDocx(Report):
                       path=CFG.PATH_LOGO,
                       height=height,
                       width=width)
-
-    def setPageBreak(self):
-        self._contents['page_break'] = '\f'
-
-    def getDox(self):
-        return self._doc.get_docx()
+    #
+    # def setPageBreak(self):
+    #     self._contents['page_break'] = '\f'
+    #
+    # def getDox(self):
+    #     return self._doc.get_docx()
 
 
 if __name__ == '__main__':
